Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(13)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutObject.h

Issue 2727253004: Call getUncachedPseudoStyle on correct node for ::selection. (Closed)
Patch Set: Documentation fixes. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutObject.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutObject.h b/third_party/WebKit/Source/core/layout/LayoutObject.h
index e4fd80eba60e87d23f215b0a8a17cbaefcf3ac8a..347bfb1c150848804d0eee24fdef8e91c22c70fc 100644
--- a/third_party/WebKit/Source/core/layout/LayoutObject.h
+++ b/third_party/WebKit/Source/core/layout/LayoutObject.h
@@ -429,10 +429,9 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
void addAbsoluteRectForLayer(IntRect& result);
bool requiresAnonymousTableWrappers(const LayoutObject*) const;
- // Gets pseudoStyle from Shadow host(in case of input elements)
- // or from Parent element.
- PassRefPtr<ComputedStyle> getUncachedPseudoStyleFromParentOrShadowHost()
- const;
+ // Gets ::selection pseudo style from Shadow host(in case of input elements)
+ // or from parent element.
+ PassRefPtr<ComputedStyle> getUncachedSelectionStyle() const;
public:
#ifndef NDEBUG

Powered by Google App Engine
This is Rietveld 408576698